@@ -3,12 +3,12 @@ package Number::Phone::JP::Table::Mobile;
 use strict;
 use warnings;
 
-our $VERSION = '0.20130501';
+our $VERSION = '0.20130603';
 
-# Table last modified: 2013-05-01
+# Table last modified: 2013-06-03
 our %TEL_TABLE = (
     # Pref => q<Assoc-Pref-Regex>,
-    80 => '(?:(?:9(?:[0-79]\d|8[0-5])|[1-8]\d{2})\d{5})',
+    80 => '(?:[1-9]\d{7})',
     90 => '(?:[1-9]\d{7})',
 );
 
